# Ruptured
A Python module that makes everything easier.

Ruptured is desigined as a module for Python, however it has diffrent functions that simplifies Python tasks.
It uses python syntax and python code.
Ruptured is a collection of shortcuts, ranging from easier windows to file reading.
We hope we can add more in the future.

Bruce Li

creator of Ruptured




 
